==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythnews/i18n/mythnews_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MythNews</name>
    <message>
        <source>Updated</source>
        <translation>Aktualisiert</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>MythNewsConfig</name>
    <message>
        <source>Press MENU to set the update frequency.</source>
        <translation>Drücken Sie &apos;Menü&apos; um die Aktualisierungsfrequenz zu ändern.</translation>
    </message>
    <message>
        <source>Set update frequency by using the up/down arrows.
The minimum allowed value is 30 Minutes.</source>
        <translation>Mit den Pfeil-Auf/Ab Tasten die Aktualisierungsfrequenz auswählen.
Das Minimum sind 30 Minuten.</translation>
    </message>
    <message>
        <source>Press MENU to return to feed selection.</source>
        <translation>Mit &apos;Menü&apos; gelangen Sie zurück zur Feed-Auswahl.</translation>
    </message>
</context>
<context>
    <name>NewsSite</name>
    <message>
        <source>Failed to retrieve news</source>
        <translation>Fehler beim Abrufen der Nachrichten.</translation>
    </message>
    <message>
        <source>Retrieve Failed. </source>
        <translation>Empfang gescheitert. </translation>
    </message>
    <message>
        <source>No Cached News</source>
        <translation>Keine zwischengespeicherten Nachrichten.</translation>
    </message>
    <message>
        <source>Failed to read downloaded file</source>
        <translation>Fehler beim Lesen der geladenen Datei.</translation>
    </message>
    <message>
        <source>Showing Cached News</source>
        <translation>Zeige zwischengespeicherte Nachrichten.</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythnews/i18n/mythnews_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MythNews</name>
    <message>
        <source>Updated</source>
        <translation>Aktualisiert</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Edit Site Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Site Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit News Site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add News Site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete News Site</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MythNewsConfig</name>
    <message>
        <source>Press MENU to set the update frequency.</source>
        <translation>Drücken Sie &apos;Menü&apos; um die Aktualisierungsfrequenz zu ändern.</translation>
    </message>
    <message>
        <source>Set update frequency by using the up/down arrows.
The minimum allowed value is 30 Minutes.</source>
        <translation>Mit den Pfeil-Auf/Ab Tasten die Aktualisierungsfrequenz auswählen.
Das Minimum sind 30 Minuten.</translation>
    </message>
    <message>
        <source>Press MENU to return to feed selection.</source>
        <translation>Mit &apos;Menü&apos; gelangen Sie zurück zur Feed-Auswahl.</translation>
    </message>
</context>
<context>
    <name>NewsSite</name>
    <message>
        <source>Failed to retrieve news</source>
        <translation>Fehler beim Abrufen der Nachrichten.</translation>
    </message>
    <message>
        <source>Retrieve Failed. </source>
        <translation>Empfang gescheitert. </translation>
    </message>
    <message>
        <source>No Cached News</source>
        <translation>Keine zwischengespeicherten Nachrichten.</translation>
    </message>
    <message>
        <source>Failed to read downloaded file</source>
        <translation>Fehler beim Lesen der geladenen Datei.</translation>
    </message>
    <message>
        <source>Showing Cached News</source>
        <translation>Zeige zwischengespeicherte Nachrichten.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>MythNews</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this news site

%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
</context>
</TS>
